@@ -10,6 +10,7 @@
 """
 from . import mat_documenters as doc
 from . import mat_directives
+from . import mat_types
 
 import re
 
@@ -40,15 +41,6 @@ mat_sig_re = re.compile(
 )
 
 
-def strip_package_prefix(varname):
-    """Remove the leading '+' prefix on package names"""
-
-    if not varname:
-        return varname
-
-    return ".".join([s.lstrip("+") for s in varname.split(".")])
-
-
 def _pseudo_parse_arglist(signode, arglist):
     """ "Parse" a list of arguments separated by commas.
 
@@ -179,9 +171,9 @@ class MatObject(ObjectDescription):
         modname = self.options.get("module", self.env.temp_data.get("mat:module"))
 
         if not self.env.config.matlab_keep_package_prefix:
-            modname = strip_package_prefix(modname)
-            name_prefix = strip_package_prefix(name_prefix)
-            name = strip_package_prefix(name)
+            modname = mat_types.strip_package_prefix(modname)
+            name_prefix = mat_types.strip_package_prefix(name_prefix)
+            name = mat_types.strip_package_prefix(name)
 
         classname = self.env.temp_data.get("mat:class")
         if classname:
@@ -220,9 +212,21 @@ class MatObject(ObjectDescription):
         # 'exceptions' module.
         elif add_module and self.env.config.add_module_names:
             modname = self.options.get("module", self.env.temp_data.get("mat:module"))
-            if modname and modname != "exceptions":
+
+            if self.env.config.matlab_short_links:
+                # modname is only used for package names
+                # - "target.+package" => "package"
+                # - "target" => ""
+                parts = modname.split(".")
+                parts = [part for part in parts if part.startswith("+")]
+                modname = ".".join(parts)
+
+            # Consider adding the module name, except for "." and "exceptions"
+            # - This avoids the ".." for root entities.
+            if modname and (modname not in (".", "exceptions")):
                 if not self.env.config.matlab_keep_package_prefix:
-                    modname = strip_package_prefix(modname)
+                    modname = mat_types.strip_package_prefix(modname)
+
                 nodetext = modname + "."
                 signode += addnodes.desc_addname(nodetext, nodetext)
 
@@ -252,34 +256,45 @@ class MatObject(ObjectDescription):
 
     def add_target_and_index(self, name_cls, sig, signode):
         modname = self.options.get("module", self.env.temp_data.get("mat:module"))
+
+        if self.env.config.matlab_short_links:
+            # modname is only used for package names
+            # - "target.+package" => "package"
+            # - "target" => ""
+            parts = modname.split(".")
+            parts = [part for part in parts if part.startswith("+")]
+            modname = ".".join(parts)
+
         fullname = (modname and modname + "." or "") + name_cls[0]
+        fullname = fullname.lstrip(".")
 
         if not self.env.config.matlab_keep_package_prefix:
-            modname_out = strip_package_prefix(modname)
+            modname_out = mat_types.strip_package_prefix(modname)
             fullname_out = (modname_out and modname_out + "." or "") + name_cls[0]
+            fullname_out = fullname_out.lstrip(".")
         else:
             modname_out, fullname_out = modname, fullname
 
         # note target
-        if fullname not in self.state.document.ids:
+        if fullname_out not in self.state.document.ids:
             signode["names"].append(fullname_out)
-            signode["ids"].append(fullname)
+            signode["ids"].append(fullname_out)
             signode["first"] = not self.names
             self.state.document.note_explicit_target(signode)
             objects = self.env.domaindata["mat"]["objects"]
-            if fullname in objects:
+            if fullname_out in objects:
                 self.state_machine.reporter.warning(
-                    "duplicate object description of %s, " % fullname
+                    "duplicate object description of %s, " % fullname_out
                     + "other instance in "
-                    + self.env.doc2path(objects[fullname][0])
+                    + self.env.doc2path(objects[fullname_out][0])
                     + ", use :noindex: for one of them",
                     line=self.lineno,
                 )
-            objects[fullname] = (self.env.docname, self.objtype)
+            objects[fullname_out] = (self.env.docname, self.objtype)
 
         indextext = self.get_index_text(modname_out, name_cls)
         if indextext:
-            entry = ("single", indextext, fullname, "", None)
+            entry = ("single", indextext, fullname_out, "", None)
             self.indexnode["entries"].append(entry)
 
     def before_content(self):
@@ -474,7 +489,7 @@ class MatModule(Directive):
         modname = self.arguments[0].strip()
 
         if not env.config.matlab_keep_package_prefix:
-            modname_out = strip_package_prefix(modname)
+            modname_out = mat_types.strip_package_prefix(modname)
         else:
             modname_out = modname
 
@@ -541,7 +556,7 @@ class MatXRefRole(XRefRole):
                     title = title[dot + 1 :]
 
             if not env.config.matlab_keep_package_prefix:
-                title = strip_package_prefix(title)
+                title = mat_types.strip_package_prefix(title)
 
         # if the first character is a dot, search more specific namespaces first
         # else search builtins first
@@ -590,7 +605,7 @@ class MATLABModuleIndex(Index):
 
             # Create nice mod-name
             if not self.domain.env.config.matlab_keep_package_prefix:
-                modname_out = strip_package_prefix(modname)
+                modname_out = mat_types.strip_package_prefix(modname)
             else:
                 modname_out = modname
 
@@ -825,13 +840,31 @@ class MATLABDomain(Domain):
         return ret
 
 
+def analyze(app):
+    mat_types.analyze(app)
+
+
+def ensure_configuration(app, env):
+    if env.matlab_short_links:
+        logger.info(
+            "[sphinxcontrib-matlabdomain] matlab_short_links=True, forcing matlab_keep_package_prefix=False."
+        )
+        env.matlab_keep_package_prefix = False
+
+
 def setup(app):
+    app.connect("config-inited", ensure_configuration)
+    app.connect("builder-inited", analyze)
+
     app.add_domain(MATLABDomain)
     # autodoc
     app.add_config_value("matlab_src_dir", None, "env")
     app.add_config_value("matlab_src_encoding", None, "env")
-    app.add_config_value("matlab_keep_package_prefix", True, "env")
+    app.add_config_value("matlab_keep_package_prefix", False, "env")
     app.add_config_value("matlab_show_property_default_value", False, "env")
+    app.add_config_value("matlab_short_links", False, "env")
+    app.add_config_value("matlab_auto_link", None, "env")
+    app.add_config_value("matlab_class_signature", False, "env")
 
     app.registry.add_documenter("mat:module", doc.MatModuleDocumenter)
     app.add_directive_to_domain(
