@@ -4,18 +4,19 @@ Created on Mon Jan  6 09:14:07 2020
 @author: ajw5
 """
 
+
 class PythonClass:
-    '''
+    """
     [basic python class to not do anything]
-    
+
     :param [nonexistant_parameter]: None!
-    '''
-    
-    def member1(self,param1):
-        '''
+    """
+
+    def member1(self, param1):
+        """
         [get a string]
-        
+
         :param [param1]: test parameter
         :return: 'this is a member' string
-        '''
-        return 'this is a member'
\ No newline at end of file
+        """
+        return "this is a member"
