@@ -1,17 +1,15 @@
 #! /usr/bin/env python
 # -*- coding: utf-8 -*-
 from sphinxcontrib import mat_documenters as doc
-from sphinxcontrib.mat_types import modules
-import os
-import sys
+from sphinxcontrib.mat_types import entities_table
+import helper
 import pytest
 
 from sphinx.testing.fixtures import test_params, make_app
-from sphinx.testing.path import path
 
 
-rootdir = path(os.path.dirname(__file__)).abspath()
-matlab_src_dir = os.path.join(rootdir, "test_data")
+rootdir = helper.rootdir(__file__)
+matlab_src_dir = str(rootdir / "test_data")
 doc.MatObject.basedir = matlab_src_dir
 
 
@@ -29,8 +27,8 @@ def mod(app):
     return doc.MatObject.matlabify("test_data")
 
 
-def test_empty():
-    assert doc.MatObject.matlabify("") is None
+# def test_empty():
+#     assert doc.MatObject.matlabify("") is None
 
 
 def test_unknown():
@@ -49,10 +47,12 @@ def test_module(mod):
     assert mod.getter("__package__") == "test_data"
     assert not mod.getter("__module__")
     assert not mod.getter("__doc__")
-    all_items = set(mod.getter("__all__"))
+    all_entities = mod.getter("__all__")
+    all_items = set(name for name, entity in all_entities)
     expected_items = {
         "+package",
         "@ClassFolder",
+        "Application",
         "ClassAbstract",
         "ClassExample",
         "ClassBySource",
@@ -66,6 +66,7 @@ def test_module(mod):
         "Bool",
         "ClassWithEvent",
         "f_no_input_no_output_no_parentheses",
+        "f_no_input_no_parentheses_no_docstring",
         "ClassWithCommentHeader",
         "f_with_comment_header",
         "f_with_dummy_argument",
@@ -108,9 +109,11 @@ def test_module(mod):
         "ClassWithLongPropertyDocstrings",
         "ClassWithLongPropertyTrailingEmptyDocstrings",
         "ClassWithPropertyValidators",
+        "ClassWithTrailingCommentAfterBases",
+        "ClassWithTrailingSemicolons",
     }
     assert all_items == expected_items
-    assert mod.getter("__name__") in modules
+    assert mod.getter("__name__") in entities_table
 
 
 def test_parse_twice(mod):
@@ -249,7 +252,8 @@ def test_folder_class(mod):
     assert func.retv == ["varargout"]
     assert (
         func.docstring
-        == " CLASSMETHOD A function within a package\n\n :param obj: An instance of this class.\n :param varargin: Variable input arguments.\n :returns: varargout\n"
+        == " CLASSMETHOD A function within a package\n\n :param obj: An instance of this class.\n"
+        " :param varargin: Variable input arguments.\n :returns: varargout\n"
     )
 
 
