@@ -210,6 +210,18 @@ def test_no_input_no_output_no_parentheses():
     )
 
 
+def test_no_input_no_parentheses_no_docstring():
+    mfile = os.path.join(
+        DIRNAME, "test_data", "f_no_input_no_parentheses_no_docstring.m"
+    )
+    obj = mat_types.MatObject.parse_mfile(
+        mfile, "f_no_input_no_parentheses_no_docstring", "test_data"
+    )
+    assert obj.name == "f_no_input_no_parentheses_no_docstring"
+    assert obj.retv == ["result"]
+    assert obj.args is None
+
+
 def test_ClassWithCommentHeader():
     mfile = os.path.join(DIRNAME, "test_data", "ClassWithCommentHeader.m")
     obj = mat_types.MatObject.parse_mfile(mfile, "ClassWithCommentHeader", "test_data")
@@ -456,7 +468,8 @@ def test_f_with_name_mismatch(caplog):
         (
             "sphinx.matlab-domain",
             WARNING,
-            '[sphinxcontrib-matlabdomain] Unexpected function name: "f_name_with_mismatch". Expected "f_with_name_mismatch" in module "test_data".',
+            '[sphinxcontrib-matlabdomain] Unexpected function name: "f_name_with_mismatch".'
+            ' Expected "f_with_name_mismatch" in module "test_data".',
         ),
     ]
 
@@ -534,7 +547,8 @@ def test_ClassWithNameMismatch(caplog):
         (
             "sphinx.matlab-domain",
             WARNING,
-            '[sphinxcontrib-matlabdomain] Unexpected class name: "ClassWithMismatch". Expected "ClassWithNameMismatch" in "test_data.ClassWithNameMismatch".',
+            '[sphinxcontrib-matlabdomain] Unexpected class name: "ClassWithMismatch". '
+            'Expected "ClassWithNameMismatch" in "test_data.ClassWithNameMismatch".',
         ),
     ]
 
@@ -713,7 +727,7 @@ def test_ClassWithLongPropertyDocstrings():
     assert obj.properties["b"]["docstring"] == " Document this property\n"
 
 
-def test_ClassWithLongPropertyDocstrings():
+def test_ClassWithLongPropertyTrailingEmptyDocstrings():
     mfile = os.path.join(
         TESTDATA_ROOT, "ClassWithLongPropertyTrailingEmptyDocstrings.m"
     )
@@ -740,5 +754,96 @@ def test_ClassWithPropertyValidators():
     assert obj.properties["ReportLevel"]["docstring"] == " The report level\n"
 
 
+def test_ClassWithTrailingCommentAfterBases():
+    mfile = os.path.join(TESTDATA_ROOT, "ClassWithTrailingCommentAfterBases.m")
+    obj = mat_types.MatObject.parse_mfile(
+        mfile, "ClassWithTrailingCommentAfterBases", "test_data"
+    )
+    assert obj.name == "ClassWithTrailingCommentAfterBases"
+    assert obj.bases == ["handle", "my.super.Class"]
+    assert (
+        obj.docstring
+        == " test class methods\n\n :param a: the input to :class:`ClassWithTrailingCommentAfterBases`\n"
+    )
+    mymethod = obj.methods["mymethod"]
+    assert mymethod.name == "mymethod"
+    assert mymethod.retv == ["c"]
+    assert mymethod.args == ["obj", "b"]
+    assert (
+        mymethod.docstring
+        == " a method in :class:`ClassWithTrailingCommentAfterBases`\n\n :param b: an input to :meth:`mymethod`\n"
+    )
+
+
+def test_ClassWithEllipsisProperties():
+    mfile = os.path.join(TESTDATA_ROOT, "ClassWithEllipsisProperties.m")
+    obj = mat_types.MatObject.parse_mfile(
+        mfile, "ClassWithEllipsisProperties", "test_data"
+    )
+    assert obj.name == "ClassWithEllipsisProperties"
+    assert obj.bases == ["handle"]
+    assert obj.docstring == " stuff\n"
+    assert len(obj.methods) == 0
+
+    assert obj.properties["A"]["docstring"] == " an expression with ellipsis"
+    assert obj.properties["A"]["default"] == "1+2+3+4+5"
+    assert (
+        obj.properties["B"]["docstring"]
+        == " a cell array with ellipsis and other array notation"
+    )
+    assert obj.properties["B"]["default"].startswith("{'hello','bye';")
+    assert obj.properties["B"]["default"].endswith("}")
+    assert obj.properties["C"]["docstring"] == " using end inside array"
+    assert obj.properties["C"]["default"] == "ClassWithEllipsisProperties.B(2:end,1)"
+    assert obj.properties["D"]["docstring"] == " String with line continuation"
+    assert obj.properties["D"]["default"] == "'...'"
+    assert obj.properties["E"]["docstring"] == " The string with spaces"
+    assert obj.properties["E"]["default"] == "'some string with spaces'"
+
+
+#         mymethod.docstring
+#         == " a method in :class:`ClassWithTrailingCommentAfterBases`\n\n :param b: an input to :meth:`mymethod`\n"
+#     )
+
+
+#  A = 1 + 2 + 3 + ... my butt
+#             4 + 5; % an expression with ellipsis
+#         B = {'hello', 'bye'; ...
+#             'foo', 'bar';
+#             'this', 'that'
+#             'also' 'too'
+#             } % a cell array with ellipsis and other array notation
+#         C = ClassWithEllipsisProperties.B(2:end, 1) % using end inside array
+#         D = '...'; % String with line continuation
+
+
+def test_ClassWithTrailingSemicolons():
+    mfile = os.path.join(TESTDATA_ROOT, "ClassWithTrailingSemicolons.m")
+    obj = mat_types.MatObject.parse_mfile(
+        mfile, "ClassWithTrailingSemicolons", "test_data"
+    )
+    assert (
+        obj.docstring
+        == " Smoothing like it is performed withing Cxx >v7.0 (until v8.2 at least).\n Uses constant 228p_12k frequency vector:\n"
+    )
+    assert obj.bases == ["hgsetget"]
+    assert list(obj.methods.keys()) == [
+        "ClassWithTrailingSemicolons",
+        "CxxSmoothing",
+        "CalculateSigma",
+    ]
+    assert list(obj.properties.keys()) == [
+        "m_dSmoothingWidth",
+        "m_nExtL",
+        "m_nExtR",
+        "m_dSigmaSquared",
+        "m_dFreqExtended",
+        "m_dFreqLeft",
+        "m_dFreqRight",
+        "m_dBandWidth",
+        "m_dFreq",
+    ]
+
+
 if __name__ == "__main__":
     pytest.main([os.path.abspath(__file__)])
